const fs = require('fs')
const path = require('path')
const rollup = require('rollup')
const uglify = require('uglify-js')

let builds = require('./config').getAllBuilds()

build(builds)

function build (builds) {
	let built = 0
	const total = builds.length
	const next = () => {
		buildEntry(builds[built]).then(() => {
			built++
			if (built < total) {
				next()
			}
		}).catch(logError)
	};
	
	next()
}

/*
* https://github.com/rollup/rollup/issues/2459
* */

function buildEntry (config) {
	const output = config.output
	const { file, banner } = output
	const isProd = /min\.js$/.test(file)
	return rollup.rollup(config)
		.then(bundle => bundle.generate(output))
		.then(({ code }) => {
			if (isProd) {
				var minified = code;
				// var minified = (banner ? banner + '\n' : '') + uglify.minify(code).code;
				return write(file, minified)
			} else {
				return write(file, code)
			}
		})
}

function write (dest, code) {
	return new Promise((resolve, reject) => {
		function report () {
			console.log(blue(path.relative(process.cwd(), dest)) + ' ' + getSize(code))
			resolve()
		}
		fs.writeFile(dest, code, err => {
			if (err) return reject(err)
			report()
		})
	})
}

function logError (e) {
	console.log(e)
}

function getSize (code) {
	return (code.length / 1024).toFixed(2) + 'kb'
}

function blue (str) {
	return '\x1b[1m\x1b[34m' + str + '\x1b[39m\x1b[22m'
}