const fs = require('fs')
const path = require('path')
const babel = require('rollup-plugin-babel')

const version = JSON.stringify(require('../package.json').version);

/*
* https://github.com/rollup/rollup/issues/2459
* */

const banner = `/*!
 * Version: ${version}
 * ${fs.readFileSync('./LICENSE', 'utf8')}
 *
 */`;

const resolve = p => {
	return path.resolve(__dirname, '../', p)
};

const libName = 'Cube';

const builds = {
	'cube': {
		output: {
			file: resolve('dist/cube.js'),
			format: 'umd',
			sourcemap: true,
			name: libName,
			banner
		},
		plugins: [
			babel()
		]
	},
	'cube.min': {
		output: {
			file: resolve('dist/cube.min.js'),
			format: 'umd',
			sourcemap: true,
			name: libName,
			banner
		},
		plugins: [
			babel()
		]
	},
	'cube.esm': {
		output: {
			file: resolve('dist/cube.esm.js'),
			sourcemap: true,
			format: 'esm',
			banner,
		}
	},
	'cube.esm.min': {
		output: {
			file: resolve('dist/cube.esm.min.js'),
			sourcemap: true,
			format: 'esm',
			banner,
		}
	},
};

const input = path.resolve(__dirname, '../src/Cube.js');

function genConfig(name){
	const opts = builds[name];
	return {
		input,
		...opts,
	};
}

exports.getAllBuilds = () => Object.keys(builds).map(genConfig);
